//
//  NFCWriteViewController.m
//  AsReader 6Combo
//
//  Created by mac on 2019/2/13.
//

#import "NFCWriteViewController.h"
#import "ModelSettings.h"
#import "GlobalDefine.h"
#import "Utils.h"
#import <AsReaderDockSDK/AsReaderDockSDK.h>

typedef NS_ENUM (NSUInteger, NFCWriteOptions) {
    NFCWriteSingleBlock = 0,
    NFCWriteBytes,
};

@interface NFCWriteViewController ()<UITextFieldDelegate, AsReaderNFCDeviceDelegate>

@property (weak, nonatomic) IBOutlet UITextField *uidTextField;
@property (weak, nonatomic) IBOutlet UITextField *blockIndexTextField;
@property (weak, nonatomic) IBOutlet UITextField *writeDataTextFiled;
@property (weak, nonatomic) IBOutlet UIButton *writeButton;
@property (weak, nonatomic) IBOutlet UISegmentedControl *segmentControl;
@property (weak, nonatomic) IBOutlet UITextView *explainTextView;
@end

@implementation NFCWriteViewController {
    NFCWriteOptions nfcWriteOptions;
}

#pragma mark - Lifecycle
//----------------------------------------------------------------
- (void)viewDidLoad
{
    [super viewDidLoad];
    
    self.writeButton.layer.masksToBounds = YES;
    self.writeButton.layer.cornerRadius = 5;

    NSDictionary *dic  = [[ModelSettings sharedInstance].m_arReadTagData objectAtIndex:[ModelSettings sharedInstance].m_nSelectTagNum];
    NSString *UIDString = [dic objectForKey:df_CELL_TAG_INFO];
    NSMutableString *string = [[NSMutableString alloc] init];
    for (int i = 1 ; i < 9; i++) {
        [string appendString: [UIDString substringWithRange:NSMakeRange(UIDString.length - i*2 , 2)]];
    }
    NSLog(@"%@ %@",string,UIDString);
    self.uidTextField.text = [string uppercaseString];
    nfcWriteOptions = NFCWriteSingleBlock;
    self.segmentControl.selectedSegmentIndex = nfcWriteOptions;
    [self nfcWriteParamsExplain:nfcWriteOptions];
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    [AsReaderNFCDevice sharedInstance].delegateNFC = self;
}

- (void)viewWillDisappear:(BOOL)animated
{
    [super viewWillDisappear:animated];
    [AsReaderNFCDevice sharedInstance].delegateNFC = nil;
}

#pragma mark - Private method
//----------------------------------------------------------------
- (void)nfcWriteParamsExplain:(NFCWriteOptions)explanin
{
    if (explanin == NFCWriteSingleBlock) {
        self.explainTextView.text = @"Writes data to the specified Block area of the NFC tag, requiring the length（bytes） of the written data equaling the length of the target Block area.";
    } else {
        self.explainTextView.text = @"Writes data to the specified Block area of the NFC tag. If the length of the written data (bytes) is less than the size of the target Block area, the rest of the area will be filled with 0 automatically; and if the length of the write exceeds the size of the target Block area, the rest of the data is automatically written to the next Block area, and so on.";
    }
}

#pragma mark - UIEvent
//----------------------------------------------------------------
- (void)touchesBegan:(NSSet<UITouch *> *)touches withEvent:(UIEvent *)event
{
    [self.view endEditing:YES];
}

#pragma mark - UITextField delegate
//----------------------------------------------------------------
- (BOOL)textField:(UITextField *)textField shouldChangeCharactersInRange:(NSRange)range replacementString:(NSString *)string
{
    if ([Utils isCorrectWriteData:[textField.text stringByAppendingString:string]]) {
        return YES;
    } else {
        return NO;
    }
}


#pragma mark - IBAction
//----------------------------------------------------------------
- (IBAction)onClickWriteButton:(id)sender
{
    [self.view endEditing:YES];
    if ( [Utils checkNumberTextLength:self.blockIndexTextField.text maxNumber:255 minNumber:0]==NO ) {
        [Utils showAlert:@"" message:@"The value of the block index is in the range 0-255. Please enter a valid value" view:self];
        return;
    } else {
        if (nfcWriteOptions == NFCWriteSingleBlock) {
            [[AsReaderNFCDevice sharedInstance] writeSingleBlockWithBlockIndex:[self.blockIndexTextField.text intValue] writeData:[Utils convertHexStrToData:self.writeDataTextFiled.text] uid:[Utils convertHexStrToData:self.uidTextField.text]];
        } else {
            [[AsReaderNFCDevice sharedInstance] writeBytesWithBlockIndex:[self.blockIndexTextField.text intValue] writeData:[Utils convertHexStrToData:self.writeDataTextFiled.text] uid:[Utils convertHexStrToData:self.uidTextField.text]];
        }
    }
}

- (IBAction)onClickSegment:(UISegmentedControl *)sender
{
    nfcWriteOptions = self.segmentControl.selectedSegmentIndex;
    [self nfcWriteParamsExplain:nfcWriteOptions];
}

#pragma mark - NFC delegate
//----------------------------------------------------------------
- (void)nfcDataReceived:(NSData *)data
{
    NSLog(@"nfcDataReceived APP: %@",data);
}

- (void)nfcWriteSingleBlockStatusCode:(SDK4StatusCode)statusCode
{
    [self checkStatusCode:statusCode];
}

- (void)nfcWriteBytesStatusCode:(SDK4StatusCode)statusCode
{
    [self checkStatusCode:statusCode];
}

- (void)checkStatusCode:(SDK4StatusCode)statusCode
{
    if (statusCode == SDK4_STS_OK) {
        [Utils showAlert:@"Write Success" message:@"" view:self];
    } else {
        [Utils showAlert:@"Write Failed" message:[NSString stringWithFormat:@"StatusCode：0x%02lx", (unsigned long)statusCode] view:self];
    }
}

@end
